
.. autosummary::
    :toctree: _source/
    
################################
Development team
################################

PowNet is the result of contributions from several individuals over its development history.

**Current Development Team (Version 2.0.0 onwards)**

* Phumthep Bunnak
* Hisham Chowdhury
* Zhuoer Feng
* Stefano Galelli


**Initial Development Team (Version 1.0.0)**

* AFM Kamal Chowdhury
* Rachel Koh
* Jia Yi Ng
* Stefano Galelli
